import setuptools

setuptools.setup(
    name="trusuggest",
    version="1.0.5",
    author="Rocking Rohit",
    url="https://github.com/rocking-rohit/trusuggest-python",
    packages=setuptools.find_packages()
)